Here are some tests for various things which are not sentence endings, and should not be fixed up with double spaces: Some titles (which actually shouldn't all have a final dot according to some grammar rules, but nevermind...): Mr. Jones said hello to Mrs. Smith and Messrs. Costeau & Filou. We might also look at some other examples, e.g. (without the correct comma following the final dot) military titles like Lt. Anderson, and others, viz. Prof. Foo and Dr. Barbara. We have however been requested to generate end-of-sentence spacing for things like this sentence: OCB encryption protects the confidentiality of P and the authenticity of A, N, and P. This is obviously in conflict with the correct rendering of Anon Y. Name, so a workaround for that case, with &nbsp; will have to be used for correct rendering. End of test.

What about addresses: 192.168.20.0/16, 192.168.0.0/24, 192.168.0.0/30, and prefix length indications like /48 /56 /64 /72 /80 /88 /96 and so on? These should not be broken after the forward slash.

Either both or neither of body.smime-serial and body.smime-issuer should be present in an Authentication-Results header field. body.smime-serial and body.smime-issuer are used for cases when body.smime-identifier (email address) can't be derived by the entity adding the corresponding Authentication-Results header field. For example this can be used when gatewaying from X.400.